@@ -227,12 +227,14 @@ class BasicDataApi(object):
             except Exception as e:
                 print('Failed to get data <err_msg> {}'.format(e))
 
-    def get_index_price(self, index_list):
+    def get_index_price(self, index_list: Tuple[str] = ()):
         with BasicDatabaseConnector().managed_session() as db_session:
             try:
                 query = db_session.query(
                         IndexPrice
-                ).filter(
+                )
+                if index_list:
+                    query = query.filter(
                         # We could query all fund_ids at one time
                         IndexPrice.index_id.in_(index_list),
                     )
@@ -404,3 +406,55 @@ class BasicDataApi(object):
             except Exception as e:
                 print(f'Failed to get time range data <err_msg> {e} from {StyleAnalysisStockFactor.__tablename__}')
                 return
+
+    def get_fund_hold_asset(self, dt) -> pd.DataFrame:
+       with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                        FundHoldAsset
+                        ).filter(
+                            FundHoldAsset.datetime == dt
+                        )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get time range data <err_msg> {e} from {FundHoldAsset.__tablename__}')
+                return
+                
+    def get_fund_hold_industry(self, dt) -> pd.DataFrame:
+       with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                        FundHoldIndustry
+                        ).filter(
+                            FundHoldIndustry.datetime == dt
+                        )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get time range data <err_msg> {e} from {FundHoldIndustry.__tablename__}')
+                return
+    
+    def get_fund_hold_stock(self, dt) -> pd.DataFrame:
+       with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                        FundHoldStock
+                        ).filter(
+                            FundHoldStock.datetime == dt
+                        )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get time range data <err_msg> {e} from {FundHoldStock.__tablename__}')
+                return
+    
+    def get_fund_hold_bond(self, dt) -> pd.DataFrame:
+       with BasicDatabaseConnector().managed_session() as db_session:
+            try:
+                query = db_session.query(
+                        FundHoldBond
+                        ).filter(
+                            FundHoldBond.datetime == dt
+                        )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print(f'Failed to get time range data <err_msg> {e} from {FundHoldBond.__tablename__}')
+                return
\ No newline at end of file
