@@ -24,7 +24,7 @@ class DerivedDataApi(object):
                     )
                 tag_df = pd.read_sql(query.statement, query.session.bind)
                 return tag_df
-            
+
             except Exception as e:
                 print('Failed to get data <err_msg> {}'.format(e))
 
@@ -42,44 +42,47 @@ class DerivedDataApi(object):
 
             except Exception as e:
                 print('Failed to get data <err_msg> {}'.format(e))
-        
+
+    def get_fund_indicator_monthly(self, start_date, end_date, fund_list, columns: Tuple[str] = ()):
+        with DerivedDatabaseConnector().managed_session() as quant_session:
+            try:
+                query = quant_session.query(
+                    FundIndicatorMonthly.fund_id,
+                    FundIndicatorMonthly.datetime,
+                )
+                if columns:
+                    query = query.add_columns(*columns)
+                query = query.filter(
+                    FundIndicatorMonthly.fund_id.in_(fund_list),
+                    FundIndicatorMonthly.datetime >= start_date,
+                    FundIndicatorMonthly.datetime <= end_date
+                )
+                return pd.read_sql(query.statement, query.session.bind)
+            except Exception as e:
+                print('Failed to get data <err_msg> {}'.format(e))
+
     def get_fund_score(self):
         with DerivedDatabaseConnector().managed_session() as quant_session:
             try:
                 query = quant_session.query(
-                        FundScore,   
+                        FundScore,
                     )
                 tag_df = pd.read_sql(query.statement, query.session.bind)
                 return tag_df
-            
+
             except Exception as e:
                 print('Failed to get data <err_msg> {}'.format(e))
 
-    def get_index_valuation(self, index_id, start_date):
-        with DerivedDatabaseConnector().managed_session() as mn_session:
-            try:
-                query = mn_session.query(
-                    IndexValuation
-                ).filter(
-                    IndexValuation.index_id == index_id,
-                    IndexValuation.datetime >= start_date,
-                ).order_by(IndexValuation.datetime.asc())
-                df = pd.read_sql(query.statement, query.session.bind)
-                return df
-            except Exception as e:
-                print(e)
-                return pd.DataFrame([])
-
     def get_index_valuation_develop(self, index_ids, start_date, end_date):
         with DerivedDatabaseConnector().managed_session() as mn_session:
             try:
                 query = mn_session.query(
-                    IndexValuationDevelop
+                    IndexValuation
                 ).filter(
-                    IndexValuationDevelop.index_id.in_(index_ids),
-                    IndexValuationDevelop.datetime >= start_date,
-                    IndexValuationDevelop.datetime <= end_date,
-                ).order_by(IndexValuationDevelop.datetime.asc())
+                    IndexValuation.index_id.in_(index_ids),
+                    IndexValuation.datetime >= start_date,
+                    IndexValuation.datetime <= end_date,
+                ).order_by(IndexValuation.datetime.asc())
                 df = pd.read_sql(query.statement, query.session.bind)
                 return df
             except Exception as e:
@@ -90,10 +93,10 @@ class DerivedDataApi(object):
         with DerivedDatabaseConnector().managed_session() as mn_session:
             try:
                 query = mn_session.query(
-                    IndexValuationDevelop
+                    IndexValuation
                 ).filter(
-                    IndexValuationDevelop.index_id.in_(index_ids),
-                ).order_by(IndexValuationDevelop.datetime.asc())
+                    IndexValuation.index_id.in_(index_ids),
+                ).order_by(IndexValuation.datetime.asc())
                 df = pd.read_sql(query.statement, query.session.bind)
                 return df
             except Exception as e:
