@@ -737,6 +737,46 @@ class RawDataApi:
                 )
                 df = pd.read_sql(query.statement, query.session.bind)
                 return df
+            except Exception as e:
+                print('Failed to get data <err_msg> {}'.format(e))
+                return None
+
+    def get_em_fund_hold_asset(self):
+        with RawDatabaseConnector().managed_session() as raw_session:
+            try:
+                query = raw_session.query(EMFundHoldAsset)
+                em_hold_asset = pd.read_sql(query.statement, query.session.bind)
+                return em_hold_asset
+            except Exception as e:
+                print('Failed to get data <err_msg> {}'.format(e))
+                return None
+
+    def get_em_fund_hold_industry(self):
+        with RawDatabaseConnector().managed_session() as raw_session:
+            try:
+                query = raw_session.query(EMFundHoldIndustry)
+                em_hold_stock = pd.read_sql(query.statement, query.session.bind)
+                return em_hold_stock
+            except Exception as e:
+                print('Failed to get data <err_msg> {}'.format(e))
+                return None
+
+    def get_em_fund_hold_stock(self):
+        with RawDatabaseConnector().managed_session() as raw_session:
+            try:
+                query = raw_session.query(EMFundHoldStock)
+                em_hold_stock = pd.read_sql(query.statement, query.session.bind)
+                return em_hold_stock
+            except Exception as e:
+                print('Failed to get data <err_msg> {}'.format(e))
+                return None
+
+    def get_em_fund_hold_bond(self):
+        with RawDatabaseConnector().managed_session() as raw_session:
+            try:
+                query = raw_session.query(EMFundHoldBond)
+                em_hold_bond = pd.read_sql(query.statement, query.session.bind)
+                return em_hold_bond
             except Exception as e:
                 print('Failed to get data <err_msg> {}'.format(e))
                 return None
\ No newline at end of file
