@@ -200,7 +200,8 @@ class BasicDataPart1:
             cm_index_price = api.get_raw_cm_index_price_df(start_date, end_date).drop(columns=['_update_time']).set_index('datetime').fillna(method='ffill')
             cxindex_index_price = api.get_cxindex_index_price_df(start_date, end_date).drop(columns=['_update_time'])
             yahoo_index_price = api.get_yahoo_index_price_df(start_date, end_date).drop(columns=['_update_time'])
-            em_id_list: Dict[str, str] = self._index_info_df[['em_id', 'index_id']].dropna().set_index('em_id').to_dict()['index_id']
+            index_info_df = self._index_info_df[self._index_info_df.price_source == IndexPriceSource.default]
+            em_id_list: Dict[str, str] = index_info_df[['em_id', 'index_id']].dropna().set_index('em_id').to_dict()['index_id']
             em_index_price = api.get_em_index_price(start_date, end_date, em_id_list.keys()).drop(columns=['_update_time'])
 
             df_list = []
@@ -501,6 +502,62 @@ class BasicDataPart1:
         df = df[con_list]
         self._data_helper._upload_basic(df, Fund_size_and_hold_rate.__table__.name)
 
+    def fund_hold_asset(self):
+        #history, update only on report date
+        em_hold_asset = RawDataApi().get_em_fund_hold_asset()
+        em_hold_asset['CODES'] = em_hold_asset.apply(lambda x : 
+                            self._data_helper._get_fund_id_from_order_book_id(x.CODES.split('.')[0], x.DATES), axis=1)
+        em_hold_asset = em_hold_asset.dropna(subset=['CODES']).drop('_update_time', axis=1)
+        name_dict = {
+            'CODES':'fund_id',
+            'DATES':'datetime',
+            'PRTSTOCKTONAV':'stock_nav_ratio',
+            'PRTBONDTONAV':'bond_nav_ratio',
+            'PRTCASHTONAV':'cash_nav_ratio',
+            'PRTOTHERTONAV':'other_nav_ratio',
+        }
+        em_hold_asset = em_hold_asset.rename(columns=name_dict)
+        self._data_helper._upload_basic(em_hold_asset, 'fund_hold_asset')
+        
+    def fund_hold_industry(self):
+        #history, update only on report date
+        em_hold_industry = RawDataApi().get_em_fund_hold_industry()
+        em_hold_industry['CODES'] = em_hold_industry.apply(lambda x : 
+                            self._data_helper._get_fund_id_from_order_book_id(x.CODES.split('.')[0], x.DATES), axis=1)
+        em_hold_industry = em_hold_industry.dropna(subset=['CODES']).drop('_update_time', axis=1)
+        name_dict = {
+            'CODES':'fund_id',
+            'DATES':'datetime',
+        }
+        em_hold_industry = em_hold_industry.rename(columns=name_dict)
+        self._data_helper._upload_basic(em_hold_industry, 'fund_hold_industry')
+
+    def fund_hold_stock(self):
+        #history, update only on report date
+        em_hold_stock = RawDataApi().get_em_fund_hold_stock()
+        em_hold_stock['CODES'] = em_hold_stock.apply(lambda x : 
+                            self._data_helper._get_fund_id_from_order_book_id(x.CODES.split('.')[0], x.DATES), axis=1)
+        em_hold_stock = em_hold_stock.dropna(subset=['CODES']).drop('_update_time', axis=1)
+        name_dict = {
+            'CODES':'fund_id',
+            'DATES':'datetime',
+        }
+        em_hold_stock = em_hold_stock.rename(columns=name_dict)
+        self._data_helper._upload_basic(em_hold_stock, 'fund_hold_stock')
+
+    def fund_hold_bond(self):
+        #history, update only on report date
+        em_hold_bond = RawDataApi().get_em_fund_hold_bond()
+        em_hold_bond['CODES'] = em_hold_bond.apply(lambda x : 
+                            self._data_helper._get_fund_id_from_order_book_id(x.CODES.split('.')[0], x.DATES), axis=1)
+        em_hold_bond = em_hold_bond.dropna(subset=['CODES']).drop('_update_time', axis=1)
+        name_dict = {
+            'CODES':'fund_id',
+            'DATES':'datetime',
+        }
+        em_hold_bond = em_hold_bond.rename(columns=name_dict)
+        self._data_helper._upload_basic(em_hold_bond, 'fund_hold_bond')
+
     def process_all(self, start_date, end_date):
         failed_tasks = []
         # Depend on RQ
@@ -515,7 +572,6 @@ class BasicDataPart1:
         # if not self.rq_stock_price(start_date, end_date):
         #     failed_tasks.append('rq_stock_price')
 
-        # TODO: Depend on RQ, change to EM
         if not self.index_price(start_date, end_date):
             failed_tasks.append('index_price')
 
