@@ -66,7 +66,12 @@ class IndexValProcess:
         self.result['datetime'] = pd.to_datetime(self.result['datetime'])
         self.result['val_score'] = score_list    
         self.result = self.result.replace(np.inf, float('nan')).replace(-np.inf, float('nan'))
-        
+
+    def filter_est_peg(self, x):
+        if x > 10000 or x < -10000:
+            return None
+        return x
+
     def process(self, start_date, end_date):
         failed_tasks = []
         try:
@@ -79,6 +84,7 @@ class IndexValProcess:
             self.result = self.result.dropna(subset=['pe_ttm','pb_mrq','ps_ttm'])
             self.result = self.result[self.result['datetime'] >= pd.to_datetime(start_date_dt)]
             self.result = self.result[self.result['datetime'] <= pd.to_datetime(end_date_dt)]
+            self.result['est_peg'] = self.result['est_peg'].map(lambda x : self.filter_est_peg(x))
             self._data_helper._upload_derived(self.result, IndexValuation.__table__.name)
         except Exception as e:
             print(e)
