@@ -301,7 +301,7 @@ class EmRawDataDownloader:
 
     def em_index_info(self, index_ids: List[str]):
         try:
-            data = c.css(','.join(index_ids), 'SHORTNAME,NAME,MAKERNAME,INDEXPROFILE', 'Ispandas=1')
+            data = c.css(','.join(index_ids), 'SHORTNAME,NAME,PUBLISHDATE,MAKERNAME,INDEXPROFILE', 'Ispandas=1')
             if not isinstance(data, pd.DataFrame):
                 if data.ErrorCode != 0:
                     print(f'failed to get index info: {data.ErrorMsg}')
@@ -412,7 +412,7 @@ class EmRawDataDownloader:
             # 更新到db
             self._data_helper._upload_raw(stock_price, EmStockPrice.__table__.name)
 
-    def em_stock_price(self, start_date: str, end_date: str):
+    def em_stock_price(self, start_date: str, end_date: str, stock_list: Tuple[str] = ()):
         try:
             # 获取区间内所有交易日
             tradedates = c.tradedates(start_date, end_date, "period=1,order=1,market=CNSESH")
@@ -423,18 +423,20 @@ class EmRawDataDownloader:
                 print(f'[em_stock_price] no trade dates, return immediately (start_date){start_date} (end_date){end_date}')
                 return
 
-            # 获取所有A股股票的ID, 功能函数-板块成分
-            # http://quantapi.eastmoney.com/Cmd/Sector?from=web
-            # 全部A股股票
-            stock_id_result = c.sector('001004', end_date)
-            if stock_id_result.ErrorCode != 0:
-                print(f'failed to get stock id list: {stock_id_result.ErrorMsg}')
-                return
+            if not stock_list:
+                # 获取所有A股股票的ID, 功能函数-板块成分
+                # http://quantapi.eastmoney.com/Cmd/Sector?from=web
+                # 全部A股股票
+                stock_id_result = c.sector('001004', end_date)
+                if stock_id_result.ErrorCode != 0:
+                    print(f'failed to get stock id list: {stock_id_result.ErrorMsg}')
+                    return
+                stock_list = stock_id_result.Codes
 
             df_list = []
             for date in tradedates.Data:
                 # 获取个股股价信息
-                temp_df = c.csd(stock_id_result.Codes,
+                temp_df = c.csd(stock_list,
                                 'OPEN,CLOSE,HIGH,LOW,PRECLOSE,AVERAGE,VOLUME,AMOUNT,TURN,TRADESTATUS,TNUM,BUYVOL,SELLVOL',
                                 date, date, 'period=1,adjustflag=1,curtype=1,order=1,market=0,Ispandas=1')
                 if not isinstance(temp_df, pd.DataFrame) and temp_df.ErrorCode != 0:
@@ -480,7 +482,7 @@ class EmRawDataDownloader:
             # 更新到db
             self._data_helper._upload_raw(stock_price, EmStockPostPrice.__table__.name)
 
-    def em_stock_post_price(self, start_date: str, end_date: str):
+    def em_stock_post_price(self, start_date: str, end_date: str, stock_list: Tuple[str] = ()):
         try:
             # 获取区间内所有交易日
             tradedates = c.tradedates(start_date, end_date, "period=1,order=1,market=CNSESH")
@@ -491,18 +493,20 @@ class EmRawDataDownloader:
                 print(f'[em_stock_post_price] no trade dates, return immediately (start_date){start_date} (end_date){end_date}')
                 return
 
-            # 获取所有A股股票的ID, 功能函数-板块成分
-            # http://quantapi.eastmoney.com/Cmd/Sector?from=web
-            # 全部A股股票
-            stock_id_result = c.sector('001004', end_date)
-            if stock_id_result.ErrorCode != 0:
-                print(f'failed to get stock id list: {stock_id_result.ErrorMsg}')
-                return
+            if not stock_list:
+                # 获取所有A股股票的ID, 功能函数-板块成分
+                # http://quantapi.eastmoney.com/Cmd/Sector?from=web
+                # 全部A股股票
+                stock_id_result = c.sector('001004', end_date)
+                if stock_id_result.ErrorCode != 0:
+                    print(f'failed to get stock id list: {stock_id_result.ErrorMsg}')
+                    return
+                stock_list = stock_id_result.Codes
 
             df_list = []
             for date in tradedates.Data:
                 # 获取个股股价信息
-                temp_df = c.csd(stock_id_result.Codes,
+                temp_df = c.csd(stock_list,
                                 'OPEN,CLOSE,HIGH,LOW,PRECLOSE,AVERAGE,VOLUME,AMOUNT,TRADESTATUS,TAFACTOR',
                                 date, date, 'period=1,adjustflag=2,curtype=1,order=1,market=0,Ispandas=1')
                 if not isinstance(temp_df, pd.DataFrame) and temp_df.ErrorCode != 0:
@@ -726,7 +730,7 @@ class EmRawDataDownloader:
             df_list = []
             for date in tradedates.Data:
                 temp_df = c.css(stock_id_result.Codes,
-                                'TOTALSHARE,HOLDFROZENAMTACCUMRATIO,ASSETMRQ,EQUITYMRQ,PETTMDEDUCTED,PBLYRN,PSTTM,AHOLDER,ESTPEG',
+                                'TOTALSHARE,HOLDFROZENAMTACCUMRATIO,PETTMDEDUCTED,PBLYRN,PSTTM,AHOLDER,ESTPEG',
                                 f'EndDate={date},TradeDate={date},PREDICTYEAR={predict_year},Ispandas=1')
                 if not isinstance(temp_df, pd.DataFrame) and temp_df.ErrorCode != 0:
                     print(f'failed to get stock daily info: {temp_df.ErrorMsg} (date){date}')
@@ -823,8 +827,7 @@ class EmRawDataDownloader:
             if index_info_df is None:
                 print(f'[em_index_val] get index info failed')
                 return False
-            index_info_df = index_info_df[index_info_df.price_source == IndexPriceSource.default]
-            em_indexes = index_info_df[index_info_df.tag_method.isin(['PE百分位', 'PB百分位'])].em_id
+            em_indexes = index_info_df[index_info_df.tag_method.isin(['PE百分位', 'PB百分位','PS百分位'])].em_id
             # 过滤掉几个特殊指数
             em_indexes = em_indexes[em_indexes.notna() & ~em_indexes.isin(['LIGBP1M.IR', 'HIBOR3M.IR', 'AU9999.SGE', 'AU0.SHF'])]
             index_list = em_indexes.to_list()
@@ -836,7 +839,7 @@ class EmRawDataDownloader:
             # 一天一天地获取
             for date in trade_day_df.TRADEDATES:
                 data = c.csd(index_list,
-                           "PETTM,PBMRQ,DIVIDENDYIELD,PSTTM,PCFTTM,ROE,EPSTTM",
+                           "PETTM,PBMRQ,PSTTM,PCFTTM,ROE,EPSTTM",
                            date, date,
                            "DelType=1,period=1,adjustflag=1,curtype=1,order=1,market=0,Ispandas=1")
                 if not isinstance(data, pd.DataFrame):
@@ -844,12 +847,15 @@ class EmRawDataDownloader:
                         print(f'failed to get index val info: {data.ErrorMsg} (date){date}')
                     break
 
+                # Caution!! 股息率补历史的话需要使用csd中的DIVIDENDYIELD，这里的DIVIDENDRATETTM只能用作每日更新
                 _y = pd.to_datetime(date).date().year + 1
-                another_data = c.css(index_list, "ESTPEG", f"TradeDate={date},PREDICTYEAR={_y},Ispandas=1")
+                another_data = c.css(index_list, "DIVIDENDRATETTM,ESTPEG", f"TradeDate={date},PREDICTYEAR={_y},Ispandas=1")
                 if not isinstance(another_data, pd.DataFrame):
                     if another_data.ErrorCode != 0:
                         print(f'failed to get index val info part 2: {another_data.ErrorMsg} (date){date}')
                     break
+                # 这里除以100与股息率历史数据保持单位一致
+                another_data['DIVIDENDRATETTM'] /= 100
                 df_list.append(data.join(another_data.drop(columns='DATES'), how='outer'))
 
             if df_list:
@@ -1188,6 +1194,72 @@ class EmRawDataDownloader:
             traceback.print_exc()
             return False
 
+    def em_fund_asset(self):
+        all_fund = c.sector('507013', '20200719').Codes
+        dt_list = ['20191231','20200331','20200630']
+        res = []
+        for dt in dt_list:
+            data=c.css(all_fund,"PRTSTOCKTONAV,PRTBONDTONAV,PRTCASHTONAV,PRTOTHERTONAV",f"ReportDate={dt},Ispandas=1")
+            data['DATES'] = dt
+            res.append(data)
+        df = pd.concat(res).reset_index()
+        self._data_helper._upload_raw(df, 'em_fund_asset')
+
+    def em_fund_industry(self):
+        all_fund = c.sector('507013', '20200719').Codes
+        dt_list = ['20191231','20200331','20200630']
+        res = []
+        rank_list = [1,2,3]
+        for dt in dt_list:
+            _res = [] 
+            for rank in rank_list:
+                data=c.css(all_fund,"PRTKEYINDNAME,PRTKEYINDTOASSET",f"ReportDate={dt},Rank={rank},IndustryCode=A,NewOldType=1,Ispandas=1")
+                data = data.rename(columns={'PRTKEYINDNAME':f'rank{rank}_indname','PRTKEYINDTOASSET':f'rank{rank}_indweight'})
+                data = data.drop('DATES',axis=1)
+                _res.append(data)
+            df = pd.concat(_res,axis=1)
+            df['DATES'] = dt
+            res.append(df)
+        df = pd.concat(res).reset_index()
+        self._data_helper._upload_raw(df, 'em_fund_industry')
+
+    def em_fund_stock(self):
+        all_fund = c.sector('507013', '20200719').Codes
+        dt_list = ['20191231','20200331','20200630']
+        res = []
+        rank_list = [i for i in range(1,11,1)]
+        for dt in dt_list:
+            _res = [] 
+            for rank in rank_list:
+                data=c.css(all_fund,"PRTKEYSTOCKNAME,PRTKEYSTOCKVALUE,PRTKEYSTOCKTONAV",f"ReportDate={dt},Rank={rank},Ispandas=1")
+                data = data.rename(columns={'PRTKEYSTOCKNAME':f'rank{rank}_stock','PRTKEYSTOCKVALUE':f'rank{rank}_stockval','PRTKEYSTOCKTONAV':f'rank{rank}_stockweight'})
+                data = data.drop('DATES',axis=1)
+                _res.append(data)
+            df = pd.concat(_res,axis=1)
+            df['DATES'] = dt
+            res.append(df)
+        df = pd.concat(res).reset_index()
+        self._data_helper._upload_raw(df, 'em_fund_stock')
+
+    def em_fund_bond(self):
+        all_fund = c.sector('507013', '20200719').Codes
+        fund_list = all_fund
+        dt_list = ['20191231','20200331','20200630']
+        res = []
+        rank_list = [i for i in range(1,11,1)]
+        for dt in dt_list:
+            _res = [] 
+            for rank in rank_list:
+                data=c.css(fund_list,"PRTKEYBONDNAME,PRTKEYBONDCODE,PRTKEYBONDVALUE,PRTKEYBONDTONAV",f"ReportDate={dt},Rank={rank},Ispandas=1")
+                data = data.rename(columns={'PRTKEYBONDNAME':f'rank{rank}_bond','PRTKEYBONDCODE':f'rank{rank}_bond_code','PRTKEYBONDVALUE':f'rank{rank}_bondval','PRTKEYBONDTONAV':f'rank{rank}_bondweight'})
+                data = data.drop('DATES',axis=1)
+                _res.append(data)
+            df = pd.concat(_res,axis=1)
+            df['DATES'] = dt
+            res.append(df)
+        df = pd.concat(res).reset_index()
+        em._data_helper._upload_raw(df, 'em_fund_bond')
+
     def download_all(self, start_date, end_date):
         failed_tasks = []
         # If em_tradedates fails, there is no trading day between start_date and end_date
