@@ -1,10 +1,10 @@
 import pandas as pd
 import traceback
+from sqlalchemy import func
 from ...wrapper.mysql import (RawDatabaseConnector, BasicDatabaseConnector, DerivedDatabaseConnector, 
     ViewDatabaseConnector)
 from ...view.view_models import FundDailyCollection
-from ...view.raw_models import RqFundIndicator
-from ...view.basic_models import FundNav, FundInfo, FundRatingLatest, FundSize
+from ...view.basic_models import FundNav, FundInfo, FundRatingLatest, FundSize, FundRet
 from ...view.derived_models import FundAlpha, FundScore, FundIndicator
 from ....constant import ExchangeStatus
 
@@ -33,44 +33,69 @@ class FundDailyCollectionProcessor(object):
             try:
                 latest_time = mn_session.query(FundNav).order_by(FundNav.datetime.desc()).limit(1).one_or_none()
                 latest_time = latest_time.datetime
+                subq = mn_session.query(
+                    FundNav.fund_id.label('temp_id'),
+                    func.max(FundNav.datetime).label('temp_date'),
+                ).group_by(FundNav.fund_id).subquery()
+
                 query = mn_session.query(
                     FundNav.fund_id,
                     FundNav.unit_net_value,
                     FundNav.acc_net_value,
                     FundNav.adjusted_net_value,
                     FundNav.datetime,
+                    FundNav.change_rate,
                     FundNav.redeem_status,
                     FundNav.subscribe_status,
-                ).filter(FundNav.datetime==latest_time)
+                ).filter(
+                    FundNav.fund_id == subq.c.temp_id,
+                    FundNav.datetime == subq.c.temp_date
+                )
 
                 nav = pd.read_sql(query.statement, query.session.bind)
                 return nav.set_index('fund_id'), latest_time
             except Exception as e:
                 print('Failed fill get data <err_msg> {}'.format(e))
 
-    # TODO: use data in basic
     def get_indicator_df(self):
-        with RawDatabaseConnector().managed_session() as quant_session:
+        with BasicDatabaseConnector().managed_session() as quant_session:
             try:
-                latest_time = quant_session.query(RqFundIndicator).order_by(RqFundIndicator.datetime.desc()).limit(1).one_or_none()
+                latest_time = quant_session.query(FundRet).order_by(FundRet.datetime.desc()).limit(1).one_or_none()
                 latest_time = latest_time.datetime
                 query = quant_session.query(
-                    RqFundIndicator.order_book_id,
-                    RqFundIndicator.annualized_returns,
-                    RqFundIndicator.annualized_risk,
-                    RqFundIndicator.average_size,
-                    RqFundIndicator.information_ratio,
-                    RqFundIndicator.last_month_return,
-                    RqFundIndicator.last_six_month_return,
-                    RqFundIndicator.last_three_month_return,
-                    RqFundIndicator.last_twelve_month_return,
-                    RqFundIndicator.last_week_return,
-                    RqFundIndicator.year_to_date_return,
-                    RqFundIndicator.to_date_return,
-                    RqFundIndicator.sharp_ratio,
-                    RqFundIndicator.max_drop_down,
-                ).filter(RqFundIndicator.datetime==latest_time)
+                    FundRet.fund_id,
+                    FundRet.annual_ret,
+                    # FundRet.annualized_risk,
+                    FundRet.vol,
+                    FundRet.avg_size,
+                    FundRet.info_ratio,
+                    FundRet.w1_ret,
+                    FundRet.m1_ret,
+                    FundRet.m3_ret,
+                    FundRet.m6_ret,
+                    FundRet.y1_ret,
+                    FundRet.y3_ret,
+                    FundRet.y5_ret,
+                    FundRet.recent_y_ret,
+                    FundRet.to_date_ret,
+                    FundRet.sharpe_ratio,
+                    FundRet.mdd,
+                ).filter(FundRet.datetime==latest_time)
                 indicator = pd.read_sql(query.statement, query.session.bind)
+                indicator = indicator.rename(columns={
+                    'annual_ret': 'annualized_returns',
+                    'info_ratio': 'information_ratio',
+                    'm1_ret': 'last_month_return',
+                    'm6_ret': 'last_six_month_return',
+                    'm3_ret': 'last_three_month_return',
+                    'y1_ret': 'last_twelve_month_return',
+                    'w1_ret': 'last_week_return',
+                    'recent_y_ret': 'year_to_date_return',
+                    'to_date_ret': 'to_date_return',
+                    'sharpe_ratio': 'sharp_ratio',
+                    'mdd': 'max_drop_down',
+                    'avg_size': 'average_size',
+                })
                 return indicator
 
             except Exception as e:
@@ -272,10 +297,7 @@ class FundDailyCollectionProcessor(object):
 
             print('处理行情')
             indicator = self.get_indicator_df()
-            indicator = indicator.dropna(subset=['order_book_id'])
-            indicator['fund_id'] = indicator['order_book_id'] + '!0'
-            indicator = indicator.drop_duplicates(subset=['order_book_id'], keep='last')
-            indicator = indicator.drop(['order_book_id'], axis=1)
+            indicator = indicator.drop_duplicates(subset=['fund_id'], keep='last')
             indicator = indicator.set_index('fund_id')
             print(indicator)
             print('-' * 100)
