@@ -185,6 +185,8 @@ class FundDataManager(DataManager):
             _tm_deriv_fetch_fund_indicator = time.time()
             self.dts.fund_indicator['index_id'] = self.dts.fund_indicator.fund_id.apply(lambda x: self.dts.fund_index_map[x])
             _tm_deriv_apply_fund_indicator = time.time()
+            self.dts.fund_indicator_annual = fetch_table(derived_session, FundIndicatorAnnual)
+            _tm_deriv_fetch_fund_indicator_annual = time.time()
             # fetch index val data from derived table, and choose different pct value for different index_id
             _tm_deriv_fetch_index_pct = time.time()
             pct_index_list = list(TaaTunerParam.POOL.keys())
@@ -246,7 +248,8 @@ class FundDataManager(DataManager):
             if print_time:
                 print(f'\t[time][deriv] fetch fund indicator: {_tm_deriv_fetch_fund_indicator - _tm_deriv_start}')
                 print(f'\t[time][deriv] apply fund indicator: {_tm_deriv_apply_fund_indicator - _tm_deriv_fetch_fund_indicator}')
-                print(f'\t[time][deriv] fetch index val: {_tm_deriv_fetch_index_pct - _tm_deriv_apply_fund_indicator}')
+                print(f'\t[time][deriv] fetch fund indicator annual: {_tm_deriv_fetch_fund_indicator_annual - _tm_deriv_apply_fund_indicator}')
+                print(f'\t[time][deriv] fetch index val: {_tm_deriv_fetch_index_pct - _tm_deriv_fetch_fund_indicator_annual}')
                 print(f'\t[time][deriv] pivot raw index: {_tm_deriv_apply_index_pct - _tm_deriv_fetch_index_pct}')
                 print(f'\t[time][deriv] process indicator weekly: {_tm_process_indicator_weekly - _tm_deriv_apply_index_pct}')
                 print(f'\t[time][deriv] process indicator monthly: {_tm_process_indicator_monthly - _tm_process_indicator_weekly}')
@@ -326,6 +329,9 @@ class FundDataManager(DataManager):
     def get_cs_index_component(self) -> pd.DataFrame:
         return self.dts.cs_index_component
 
+    def get_fund_indicator_annual(self) -> pd.DataFrame:
+        return self.dts.fund_indicator_annual
+
     def white_and_black_list_filter(self, score, score_raw, disproved_list):
         return self._score_manager._white_and_black_list_filter(score, score_raw, disproved_list)
 
