@@ -133,6 +133,10 @@ class FundInfo(Base):
     is_selected_mmf = Column(TINYINT(1)) # 是否基金规模最大的前50只货币基金(10年前有两只存在)  0 非  1 是
     national_debt_extension = Column(TINYINT(1)) # 纯债tag  0 非  1 是
     index_id_new = Column(CHAR(20)) # 基于第一业绩标准所标注的指数ID新
+    subscr_fee_detail = Column(TEXT) # 认购费率详情
+    purchase_fee_detail = Column(TEXT) # 申购费率详情
+    redeem_fee_detail = Column(TEXT) # 赎回费率详情
+    service_fee = Column(TEXT) # 销售服务费率
 
 class FundBenchmark(Base):
     '''基金业绩比较基准表'''
@@ -237,12 +241,16 @@ class FundRet(Base):
     m3_ret = Column(DOUBLE(asdecimal=False)) # 近一季度收益率
     m6_ret = Column(DOUBLE(asdecimal=False)) # 近半年收益率
     y1_ret = Column(DOUBLE(asdecimal=False)) # 近一年收益率
+    y3_ret = Column(DOUBLE(asdecimal=False)) # 近三年收益率
+    y5_ret = Column(DOUBLE(asdecimal=False)) # 近五年收益率
     to_date_ret = Column(DOUBLE(asdecimal=False)) # 成立至今收益率
     mdd = Column(DOUBLE(asdecimal=False)) # 最大回撤（成立以来）
     annual_ret = Column(DOUBLE(asdecimal=False)) # 年化收益（成立以来）
     avg_size = Column(DOUBLE(asdecimal=False)) # 平均规模（成立以来）
     sharpe_ratio = Column(DOUBLE(asdecimal=False)) # 夏普率（成立以来）
-
+    vol = Column(DOUBLE(asdecimal=False)) # 波动率（成立以来）
+    info_ratio = Column(DOUBLE(asdecimal=False)) # 信息比率（成立以来）
+    recent_y_ret = Column(DOUBLE(asdecimal=False)) # 年初至今收益率
 
 class FundRatingLatest(Base):
     '''基金最新评级'''
@@ -318,4 +326,115 @@ class FundRate(Base):
     jian_timeret = Column(CHAR(5)) #济安金信基金评级(择时能力)
     jian_track = Column(CHAR(5)) #济安金信基金评级(基准跟踪能力)
     jian_alpha = Column(CHAR(5)) #济安金信基金评级(超额收益能力) 
-    jian_fee = Column(CHAR(5)) #济安金信基金评级(整体费用)
\ No newline at end of file
+    jian_fee = Column(CHAR(5)) #济安金信基金评级(整体费用)
+
+class FundHoldAsset(Base):
+    '''基金持仓资产比例'''
+
+    __tablename__ = 'fund_hold_asset'
+
+    fund_id = Column(CHAR(10), primary_key=True)  # 基金id
+    datetime = Column(DATE, primary_key=True)  # 日期
+    stock_nav_ratio = Column(DOUBLE(asdecimal=False)) # 股票市值占基金资产净值比
+    bond_nav_ratio = Column(DOUBLE(asdecimal=False)) # 债券市值占基金资产净值比
+    cash_nav_ratio = Column(DOUBLE(asdecimal=False)) # 银行存款占基金资产净值比
+    other_nav_ratio = Column(DOUBLE(asdecimal=False)) # 其他资产占基金资产净值比
+
+class FundHoldIndustry(Base):
+    '''基金持仓前三行业'''
+
+    __tablename__ = 'fund_hold_industry'
+    
+    fund_id = Column(CHAR(10), primary_key=True) # 基金ID
+    datetime = Column(DATE, primary_key=True) # 日期
+    rank1_indname = Column(CHAR(50)) #第一排名行业名称
+    rank1_indweight = Column(DOUBLE(asdecimal=False)) #第一排名行业市值占基金资产总值比
+    rank2_indname = Column(CHAR(50)) #第二排名行业名称
+    rank2_indweight = Column(DOUBLE(asdecimal=False)) #第二排名行业市值占基金资产总值比
+    rank3_indname = Column(CHAR(50)) #第三排名行业名称
+    rank3_indweight = Column(DOUBLE(asdecimal=False)) #第三排名行业市值占基金资产总值比
+
+class FundHoldStock(Base):
+    '''基金持仓前十股票'''
+
+    __tablename__ = 'fund_hold_stock'
+
+    fund_id = Column(CHAR(10), primary_key=True) # 基金ID
+    datetime = Column(DATE, primary_key=True) # 日期
+    rank1_stock = Column(CHAR(20)) #股票名
+    rank1_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank1_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank2_stock = Column(CHAR(20)) #股票名
+    rank2_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank2_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank3_stock = Column(CHAR(20)) #股票名
+    rank3_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank3_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank4_stock = Column(CHAR(20)) #股票名
+    rank4_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank4_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank5_stock = Column(CHAR(20)) #股票名
+    rank5_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank5_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank6_stock = Column(CHAR(20)) #股票名
+    rank6_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank6_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank7_stock = Column(CHAR(20)) #股票名
+    rank7_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank7_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank8_stock = Column(CHAR(20)) #股票名
+    rank8_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank8_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank9_stock = Column(CHAR(20)) #股票名
+    rank9_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank9_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank10_stock = Column(CHAR(20)) #股票名
+    rank10_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank10_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+
+class FundHoldBond(Base):
+    '''东财基金重仓债'''
+
+    __tablename__ = 'fund_hold_bond'
+    fund_id = Column(CHAR(20), primary_key=True) # 基金ID
+    datetime = Column(DATE, primary_key=True) # 日期
+    rank1_bond = Column(CHAR(30)) #债券名
+    rank1_bond_code =  Column(CHAR(15)) # 债券id
+    rank1_bondval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank1_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank2_bond = Column(CHAR(30)) #债券名
+    rank2_bond_code =  Column(CHAR(15)) # 债券id
+    rank2_bondval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank2_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank3_bond = Column(CHAR(30)) #债券名
+    rank3_bond_code =  Column(CHAR(15)) # 债券id
+    rank3_bondval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank3_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank4_bond = Column(CHAR(30)) #债券名
+    rank4_bond_code =  Column(CHAR(15)) # 债券id
+    rank4_bondval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank4_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank5_bond = Column(CHAR(30)) #债券名
+    rank5_bond_code =  Column(CHAR(15)) # 债券id
+    rank5_bondval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank5_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank6_bond = Column(CHAR(30)) #债券名
+    rank6_bond_code =  Column(CHAR(15)) # 债券id
+    rank6_bondval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank6_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank7_bond = Column(CHAR(30)) #债券名
+    rank7_bond_code =  Column(CHAR(15)) # 债券id
+    rank7_bondval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank7_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank8_bond = Column(CHAR(30)) #债券名
+    rank8_bond_code =  Column(CHAR(15)) # 债券id
+    rank8_bondval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank8_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank9_bond = Column(CHAR(30)) #债券名
+    rank9_bond_code =  Column(CHAR(15)) # 债券id
+    rank9_bondval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank9_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank10_bond = Column(CHAR(30)) #债券名
+    rank10_bond_code =  Column(CHAR(15)) # 债券id
+    rank10_bondval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank10_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
\ No newline at end of file
