@@ -494,8 +494,6 @@ class EmStockDailyInfo(Base):
     DATES = Column('datetime', DATE, primary_key=True) # 日期
     TOTALSHARE = Column("total_share", DOUBLE(asdecimal=False), nullable=False) # 总股本
     HOLDFROZENAMTACCUMRATIO = Column('hold_frozen_amt_accum_ratio', DOUBLE(asdecimal=False))  # 控股股东累计质押数量占持股比例
-    ASSETMRQ = Column('asset_mrq', DOUBLE(asdecimal=False))  # 资产总计(MRQ)
-    EQUITYMRQ = Column('equity_mrq', DOUBLE(asdecimal=False))  # 归属母公司股东的权益(MRQ)(净资产)
     PETTMDEDUCTED = Column('pe_ttm_deducted', DOUBLE(asdecimal=False))  # 市盈率TTM(扣除非经常性损益)
     PBLYRN = Column('pb_lyr_n', DOUBLE(asdecimal=False))  # 市净率(PB，LYR)(按公告日)
     PSTTM = Column('ps_ttm', DOUBLE(asdecimal=False))  # 市销率(PS，TTM)
@@ -525,7 +523,7 @@ class EmStockInfo(Base):
     BLSWSINDCODE = Column("bl_sws_ind_code", CHAR(40), nullable=False) # 所属申万行业指数代码
     SW2014CODE = Column("sw_2014_code", CHAR(40), nullable=False) # 所属申万行业代码
     EMINDCODE2016 = Column("em_ind_code_2016", CHAR(40), nullable=False) # 所属东财行业(2016)代码
-    CITICCODE2020 = Column("citic_code_2020", CHAR(40), nullable=False) # 所属中信行业代码(2020)
+    CITICCODE2020 = Column("citic_code_2020", CHAR(40)) # 所属中信行业代码(2020)
     BLCSRCINDCODE = Column("bl_csrc_ind_code", CHAR(32), nullable=False) # 所属证监会行业指数代码
     CSRCCODENEW = Column("csrc_code_new", CHAR(16), nullable=False) # 所属证监会行业(新)代码
     CSINDCODE2016 = Column("cs_ind_code_2016", CHAR(32), nullable=False) # 所属中证行业(2016)代码
@@ -669,7 +667,7 @@ class EmIndexVal(Base):
     DATES = Column("datetime", DATE, primary_key=True) # 日期
     PETTM = Column("pe_ttm", DOUBLE(asdecimal=False)) # 市盈率PE(TTM)
     PBMRQ = Column("pb_mrq", DOUBLE(asdecimal=False)) # 市净率PB(MRQ)
-    DIVIDENDYIELD = Column("dividend_yield", DOUBLE(asdecimal=False)) # 股息率
+    DIVIDENDRATETTM = Column("dividend_yield", DOUBLE(asdecimal=False)) # 股息率
     PSTTM = Column("ps_ttm", DOUBLE(asdecimal=False)) # 市销率PS(TTM)
     PCFTTM = Column("pcf_ttm", DOUBLE(asdecimal=False)) # 市现率PCF(TTM)
     ROE = Column("roe", DOUBLE(asdecimal=False)) # 净资产收益率
@@ -917,4 +915,114 @@ class EMFundRate(Base):
     JAJXTIMESELECTIONRAT = Column(CHAR(15)) # 济安金信基金评级(择时能力)
     JAJXBENCHMARKTRACKINGRAT = Column(CHAR(15)) # 济安金信基金评级(基准跟踪能力)
     JAJXEXCESSEARNINGSRAT = Column(CHAR(15)) # 济安金信基金评级(超额收益能力)
-    JAJXTOTALFEERAT = Column(CHAR(15)) # 济安金信基金评级(整体费用)
\ No newline at end of file
+    JAJXTOTALFEERAT = Column(CHAR(15)) # 济安金信基金评级(整体费用)
+
+class EMFundHoldAsset(Base):
+    '''东财基金资产配置'''
+
+    __tablename__ = 'em_fund_asset'
+
+    CODES = Column(CHAR(20), primary_key=True) # 东财基金ID
+    DATES = Column(DATE, primary_key=True) # 日期
+    PRTSTOCKTONAV = Column(DOUBLE(asdecimal=False))#股票市值占基金资产净值比 
+    PRTBONDTONAV = Column(DOUBLE(asdecimal=False))#债券市值占基金资产净值比 
+    PRTCASHTONAV = Column(DOUBLE(asdecimal=False))#银行存款占基金资产净值比 
+    PRTOTHERTONAV = Column(DOUBLE(asdecimal=False))#其他资产占基金资产净值比
+
+class EMFundHoldIndustry(Base):
+    '''东财基金行业配置'''
+
+    __tablename__ = 'em_fund_industry'
+
+    CODES = Column(CHAR(20), primary_key=True) # 东财基金ID
+    DATES = Column(DATE, primary_key=True) # 日期
+    rank1_indname = Column(CHAR(50)) #第一排名行业名称
+    rank1_indweight = Column(DOUBLE(asdecimal=False)) #第一排名行业市值占基金资产总值比
+    rank2_indname = Column(CHAR(50)) #第二排名行业名称
+    rank2_indweight = Column(DOUBLE(asdecimal=False)) #第二排名行业市值占基金资产总值比
+    rank3_indname = Column(CHAR(50)) #第三排名行业名称
+    rank3_indweight = Column(DOUBLE(asdecimal=False)) #第三排名行业市值占基金资产总值比
+
+class EMFundHoldStock(Base):
+    '''东财基金重仓股'''
+
+    __tablename__ = 'em_fund_stock'
+    CODES = Column(CHAR(20), primary_key=True) # 东财基金ID
+    DATES = Column(DATE, primary_key=True) # 日期
+    rank1_stock = Column(CHAR(20)) #股票名
+    rank1_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank1_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank2_stock = Column(CHAR(20)) #股票名
+    rank2_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank2_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank3_stock = Column(CHAR(20)) #股票名
+    rank3_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank3_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank4_stock = Column(CHAR(20)) #股票名
+    rank4_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank4_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank5_stock = Column(CHAR(20)) #股票名
+    rank5_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank5_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank6_stock = Column(CHAR(20)) #股票名
+    rank6_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank6_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank7_stock = Column(CHAR(20)) #股票名
+    rank7_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank7_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank8_stock = Column(CHAR(20)) #股票名
+    rank8_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank8_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank9_stock = Column(CHAR(20)) #股票名
+    rank9_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank9_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank10_stock = Column(CHAR(20)) #股票名
+    rank10_stockval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank10_stockweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+
+class EMFundHoldBond(Base):
+    '''东财基金重仓债'''
+
+    __tablename__ = 'em_fund_bond'
+    CODES = Column(CHAR(20), primary_key=True) # 东财基金ID
+    DATES = Column(DATE, primary_key=True) # 日期
+    rank1_bond = Column(CHAR(30)) #债券名
+    rank1_bond_code =  Column(CHAR(15)) # 债券id
+    rank1_bondval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank1_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank2_bond = Column(CHAR(30)) #债券名
+    rank2_bond_code =  Column(CHAR(15)) # 债券id
+    rank2_bondval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank2_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank3_bond = Column(CHAR(30)) #债券名
+    rank3_bond_code =  Column(CHAR(15)) # 债券id
+    rank3_bondval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank3_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank4_bond = Column(CHAR(30)) #债券名
+    rank4_bond_code =  Column(CHAR(15)) # 债券id
+    rank4_bondval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank4_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank5_bond = Column(CHAR(30)) #债券名
+    rank5_bond_code =  Column(CHAR(15)) # 债券id
+    rank5_bondval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank5_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank6_bond = Column(CHAR(30)) #债券名
+    rank6_bond_code =  Column(CHAR(15)) # 债券id
+    rank6_bondval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank6_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank7_bond = Column(CHAR(30)) #债券名
+    rank7_bond_code =  Column(CHAR(15)) # 债券id
+    rank7_bondval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank7_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank8_bond = Column(CHAR(30)) #债券名
+    rank8_bond_code =  Column(CHAR(15)) # 债券id
+    rank8_bondval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank8_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank9_bond = Column(CHAR(30)) #债券名
+    rank9_bond_code =  Column(CHAR(15)) # 债券id
+    rank9_bondval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank9_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
+    rank10_bond = Column(CHAR(30)) #债券名
+    rank10_bond_code =  Column(CHAR(15)) # 债券id
+    rank10_bondval = Column(DOUBLE(asdecimal=False)) #持仓市值
+    rank10_bondweight = Column(DOUBLE(asdecimal=False)) #持仓权重
\ No newline at end of file
