@@ -33,6 +33,7 @@ class FundDailyCollection(Base):
     unit_net_value = Column(DOUBLE(asdecimal=False))  # 单位净值
     acc_net_value = Column(DOUBLE(asdecimal=False))  # 累积单位净值
     adjusted_net_value = Column(DOUBLE(asdecimal=False))  # 复权净值
+    change_rate = Column(DOUBLE(asdecimal=False))  # 日收益率
     found_date = Column(CHAR(20))  # 成立日期
     annualized_returns = Column(DOUBLE(asdecimal=False))  # 成立以来年化收益率
     annualized_risk = Column(DOUBLE(asdecimal=False))  # 成立以来年化风险
@@ -46,6 +47,9 @@ class FundDailyCollection(Base):
     to_date_return = Column(DOUBLE(asdecimal=False))  # 成立至今收益率
     sharp_ratio = Column(DOUBLE(asdecimal=False))  # 成立至今夏普比率
     max_drop_down = Column(DOUBLE(asdecimal=False))  # 成立至今最大回撤
+    y3_ret = Column(DOUBLE(asdecimal=False))  # 近三年收益率
+    y5_ret = Column(DOUBLE(asdecimal=False))  # 近五年收益率
+    vol = Column(DOUBLE(asdecimal=False))  # 波动率（成立以来）
 
     fund_manager = Column(CHAR(255))  # 基金经理
     company_name = Column(CHAR(64))  # 基金公司
@@ -108,6 +112,7 @@ class FundDailyCollection(Base):
             'theme': '基金主题',
             'adjusted_net_value': '累计净值',
             'unit_net_value': '净值',
+            'change_rate': '日收益率',
             'found_date': '成立日期',
             'annualized_returns': '年化收益',
             'annualized_risk': '成立以来年化风险',
@@ -120,6 +125,9 @@ class FundDailyCollection(Base):
             'year_to_date_return': '年初至今',
             'to_date_return': '成立至今',
             'sharp_ratio': '夏普比率',
+            'y3_ret': '近3年',
+            'y5_ret': '近5年',
+            'vol': '成立以来波动率',
             'max_drop_down': '最大回撤',
             'fund_manager': '基金经理',
             'company_name': '基金公司',
@@ -180,6 +188,7 @@ class IndexDailyCollection(Base):
     dy = Column(DOUBLE(asdecimal=False))  # 股息率-MMT
     pe_pct = Column(DOUBLE(asdecimal=False))  # PE百分位
     pb_pct = Column(DOUBLE(asdecimal=False))  # PB百分位
+    ps_pct = Column(DOUBLE(asdecimal=False))  # PS百分位
     val_score = Column(DOUBLE(asdecimal=False))  # 估值评分
 
     vol_datetime = Column(DATE)  # 日期
@@ -256,6 +265,7 @@ class IndexDailyCollection(Base):
             'dy': '股息率',
             'pe_pct': 'PE百分位',
             'pb_pct': 'PB百分位',
+            'ps_pct': 'PS百分位',
             'val_score': '估值评分',
             'alpha_datetime': 'alpha日期',
 
@@ -340,3 +350,16 @@ class AutomaticInvestmentCollection(Base):
     intel_y3_ret = Column(DOUBLE(asdecimal=False))  # 智能定投三年收益
     intel_y5_ret = Column(DOUBLE(asdecimal=False))  # 智能定投五年收益
 
+    @staticmethod
+    def trans_columns():
+        return {
+            'fund_id': '基金ID',
+            'price_time': '定投收益日期',
+            'y1_ret': '普通定投一年收益',
+            'y3_ret': '普通定投三年收益',
+            'y5_ret': '普通定投五年收益',
+            'intel_y1_ret': '智能定投一年收益',
+            'intel_y3_ret': '智能定投三年收益',
+            'intel_y5_ret': '智能定投五年收益',
+        }
+
