@@ -10,6 +10,7 @@ from .asset_helper import SAAHelper, TAAHelper, FAHelper
 from .trader import AssetTrader, FundTrader
 from .report import ReportHelper
 from ...data.manager.manager_fund import FundDataManager
+from ...data.manager.score import ScoreFunc
 from ...data.struct import AssetWeight, AssetPrice, AssetPosition, AssetValue
 from ...data.struct import FundPosition, TAAParam, AssetTradeParam, FundTradeParam, FAParam
 from ...util.calculator import Calculator
@@ -334,6 +335,108 @@ def four_dimensions_backtest(m,begin_date, end_date, saa, fund_param, taa_detail
     stat_df = pd.DataFrame(res).set_index('策略名称').reindex(['沪深300','战略配置','战术配置','优选基金'])[['annualized_ret','annualized_vol','sharpe','mdd','mdd_date1','mdd_date2']]
     return mv_df, stat_df, fund_annual_ret
 
+def licaimofang_backtest(m: FundDataManager, saa:AssetWeight):
+    json_path = '../../surfing/rpm/etc/licaimofang_white_list.json'
+    with open(json_path,'r') as f:
+        white_list = set(json.load(f))
+    black_list = set(['000356!0','004870!0','008593!0','007404!0','003547!0'])  #基金代码在理财魔方白名单， 对方客服回复不能交易但基金代码
+
+    taa_detail_item_mmf = TAAParam(HighThreshold = 0.95,
+                                HighStop = 0.5,
+                                HighMinus = 0.05,
+                                LowStop = -1,
+                                LowThreshold = -1,
+                                LowPlus = 0,
+                                ToMmf=True)
+
+    taa_detail= {
+        'hs300': taa_detail_item_mmf,
+        'csi500': taa_detail_item_mmf,
+        'gem': taa_detail_item_mmf,
+        'sp500rmb': taa_detail_item_mmf,
+    }
+    asset_param = AssetTradeParam()
+
+    fund_param = FundTradeParam(JudgeIndexDiff=0.06, #大类资产偏离度
+                                JudgeFundSelection=0.4, # 基金排名偏离度
+                                JudgeFundRebalance=0.8, # 基金比例平均化
+                        )
+
+    fa_param = FAParam(MaxFundNumUnderAsset=4 # 同一个大类资产下基金最多数
+                    )
+    taa_default = TAAParam()
+    saa = AssetWeight(hs300=0.14,csi500=0.25,gem=0.20,sp500rmb=0.1,national_debt=0.3,cash=1/100)
+
+
+    t = FundTrader(asset_param, fund_param)
+    end_date = datetime.date.today()
+    #end_date = datetime.date(2020,7,8)
+    begin_date = datetime.date(2012,1,1)
+    bk = FundBacktestEngine(data_manager=m, trader=t, taa_params=taa_default, fa_params=fa_param, taa_param_details=taa_detail,white_list=white_list,black_list=black_list)
+    bk.init()
+    bk.run(saa=saa, start_date=begin_date, end_date=end_date)
+    bk_result = bk.get_fund_result()
+    return bk_result
+
+def qieman_backtest(m: FundDataManager, saa:AssetWeight):
+    black_list_json = '../../surfing/rpm/etc/qieman_black_list.json'
+    white_list_json = '../../surfing/rpm/etc/qieman_white_list.json'
+    with open(white_list_json,'r') as f:
+        white_list = set(json.load(f))        
+    with open(black_list_json,'r') as f:
+        black_list = set(json.load(f))
+    taa_detail_item_mmf = TAAParam(HighThreshold = 0.95,
+                                HighStop = 0.5,
+                                HighMinus = 0.05,
+                                LowStop = -1,
+                                LowThreshold = -1,
+                                LowPlus = 0,
+                                ToMmf=True)
+
+    taa_detail= {
+        'hs300': taa_detail_item_mmf,
+        'csi500': taa_detail_item_mmf,
+        'gem': taa_detail_item_mmf,
+        'sp500rmb': taa_detail_item_mmf,
+    }
+    asset_param = AssetTradeParam()
+
+    fund_param = FundTradeParam(JudgeIndexDiff=0.06, #大类资产偏离度
+                                JudgeFundSelection=0.4, # 基金排名偏离度
+                                JudgeFundRebalance=0.8, # 基金比例平均化
+                        )
+
+    fa_param = FAParam(MaxFundNumUnderAsset=4 # 同一个大类资产下基金最多数
+                    )
+    taa_default = TAAParam()
+    saa = AssetWeight(hs300=0.14,csi500=0.25,gem=0.20,sp500rmb=0.1,national_debt=0.3,cash=1/100)
+
+    t = FundTrader(asset_param, fund_param)
+    end_date = datetime.date.today()
+    begin_date = datetime.date(2012,1,1)
+    bk = FundBacktestEngine(data_manager=m, trader=t, taa_params=taa_default, fa_params=fa_param, taa_param_details=taa_detail,white_list=white_list,black_list=black_list)
+    bk.init()
+    bk.run(saa=saa, start_date=begin_date, end_date=end_date)
+    bk_result = bk.get_fund_result()
+    return bk_result
+
+def change_score_function(m: FundDataManager, saa:AssetWeight):
+    t = FundTrader(AssetTradeParam(), FundTradeParam())
+    taa_param = TAAParam()
+    fa_param = FAParam()
+    funcs = {
+        'hs300': ScoreFunc(alpha=0, beta=-1, fee_rate=0),
+        'csi500': ScoreFunc(alpha=0, beta=-1)
+    }
+    end_date = datetime.date.today()
+    #end_date = datetime.date(2020,7,8)
+    begin_date = datetime.date(2012,1,1)
+    bk = FundBacktestEngine(data_manager=m, trader=t, taa_params=taa_param, fa_params=fa_param, fund_score_funcs=funcs)
+    bk.init()
+    bk.run(saa=saa, start_date=begin_date, end_date=end_date)
+    bk_result = bk.get_fund_result()
+    return bk_result
+
 def test():
     from ...data.manager.score import FundScoreManager
     m = FundDataManager('20150101', '20160101', score_manager=FundScoreManager())
