@@ -474,11 +474,12 @@ class FundPainter(object):
     @staticmethod
     def plot_rolling_analysis( annual_ret:pd.DataFrame, 
                                fund_annual_ret:float,
-                               year:int):
+                               year:int,
+                               index_id:'str'):
         
-        df1 = annual_ret.dropna()[['沪深300','战略配置']]
+        df1 = annual_ret.dropna()[[index_id,'战略配置']]
         index = df1.index
-        saa1 = df1.沪深300
+        saa1 = df1[index_id]
         taa1 = df1.战略配置
         df2 = annual_ret.dropna()[['战略配置','战术配置']]
         index = df2.index
@@ -488,9 +489,9 @@ class FundPainter(object):
         index = df3.index
         saa3 = df3.战术配置
         taa3 = df3.优选基金
-        df4 = annual_ret.dropna()[['沪深300','优选基金']]
+        df4 = annual_ret.dropna()[[index_id,'优选基金']]
         index = df4.index
-        saa4 = df4.沪深300
+        saa4 = df4[index_id]
         taa4 = df4.优选基金
 
         df1.plot.line(figsize=(16,6))
@@ -552,11 +553,12 @@ class FundPainter(object):
         cdf_loc = df_funds.loc[index_loc, 'cdf']
         df_funds = 1 - df_funds[['cdf']]
         df_funds[['cdf']].plot.line(figsize=(12,6), legend=None)
+        mean_ret = round(100 * abs(df_funds['cdf'] - 0.5).idxmin(),2)
         plt.scatter(index_loc, 1-cdf_loc, marker='D', color='C1', s=60)
         plt.title(f'{year}年年化收益 累积密度分布', fontsize=20)
         rate = round((1-cdf_loc)*100,2)
-        st = f'组合年化收益 {round(fund_annual_ret * 100, 3)}%  获取年化收益胜率 {rate}%'
+        st = f'组合年化收益 {round(fund_annual_ret * 100, 2)}%  获取年化收益胜率 {rate}%  50%胜率年化收益 {mean_ret}%'
         plt.suptitle(st,y=0.87,fontsize=17)
         plt.grid()
         plt.show()
- 
\ No newline at end of file
+        
\ No newline at end of file
