@@ -173,13 +173,22 @@ class HybridPainter(object):
         plt.show()
 
     @staticmethod
-    def plot_fund_alpha(fund_nav:pd.DataFrame, 
+    def plot_asset_price_ratio(fund_nav:pd.DataFrame, 
                         fund_info:pd.DataFrame, 
                         index_price:pd.DataFrame,
-                        fund_position_history:dict,
+                        score_dict:dict,
                         backtest_result:dict,
                         dts:pd.Series,
+                        saa:dict,
                         ):
+        
+        proper_number_dict = {'mmf':1} 
+        for asset, w in saa.items():
+            if asset in ['cash','mmf'] or w == 0:
+                continue
+            num = min(int(round(w / 0.05, 0)) , 4)
+            proper_number_dict[asset] = num
+        
         fund_info['trade_fee'] = fund_info['purchase_fee'] + fund_info['redeem_fee']
         fee_df = fund_info[['fund_id','trade_fee']].set_index('fund_id')
         dts = dts[(dts >=fund_nav.index[0]) & (dts <= fund_nav.index[-1])]
@@ -188,56 +197,43 @@ class HybridPainter(object):
         rebalance_date = backtest_result['rebalance_date'] + [backtest_result['market_value'].index.tolist()[-1]]
         fund_desc_name = fund_info[['fund_id','desc_name']].set_index('fund_id').to_dict()['desc_name']  
         res = {}
-        for idx, d in enumerate(rebalance_date[:-1]):
-            for fund_id in fund_position_history[d]:
-                if fund_position_history[d][fund_id]['volume'] > 0:
-                    index_id = fund_position_history[d][fund_id]['index_id']
-                    dic_i = {
-                        'start_date':d,
-                        'fund_id': fund_id,
-                        'volume':fund_position_history[d][fund_id]['volume'],
-                        'end_date':rebalance_date[idx + 1],
-                        'index_id':index_id,
-                        'price':fund_position_history[d][fund_id]['price'],
-                    }
-                    if index_id in res:
-                        res[index_id].append(dic_i)
-                    else:
-                        res[index_id] = [dic_i]
-        res_index = []
+        for idx, begin_date in enumerate(rebalance_date[:-1]):
+            end_date = rebalance_date[idx + 1]
+            for asset, num in proper_number_dict.items():
+                #print(asset, num)
+                _score_dict = score_dict[begin_date][asset]
+                _score_list = sorted(_score_dict.items(), key=lambda x:x[1], reverse=True)
+                _fund_list = [i[0] for i in _score_list]
+                dic = {
+                    'index_id':asset,
+                    'begin_date':begin_date,
+                    'end_date':end_date,
+                    'fund_list':_fund_list[:proper_number_dict[asset]]
+                }
+                if asset in res:
+                    res[asset].append(dic)
+                else:
+                    res[asset] = [dic]
+        _res = []
         for index_id in res:
-            index_df = pd.DataFrame(res[index_id])
-            _res = []
-            for idx, d in enumerate(rebalance_date[:-1]):
-                start_d = d
-                end_d = rebalance_date[idx + 1]
-                index_df_i = index_df[index_df['start_date'] == start_d]
-                fund_nav_i = fund_nav.loc[start_d:end_d,index_df_i.fund_id]
+            _index_id_res = []
+            for date_dic in res[index_id]:
+                fund_nav_i = fund_nav.loc[date_dic['begin_date']:date_dic['end_date'],date_dic['fund_list']]
                 for fund_id in fund_nav_i:
                     fund_i_fee = fee_df.loc[fund_id,'trade_fee']
                     fee_discount_l = np.linspace(1,1-fund_i_fee,fund_nav_i.shape[0])
                     fund_nav_i[fund_id] = fund_nav_i[fund_id] * fee_discount_l
-                volume_i = index_df_i[['volume','fund_id']].set_index('fund_id').T
-                _df = pd.DataFrame(fund_nav_i * volume_i.values).sum(axis=1)
-                if idx == 0:
-                    begin_value = _df.values[0]
-                _res.append(_df.diff(1).fillna(0))
-            index_ret_df = pd.concat(_res).drop_duplicates(keep='first')
-            index_ret_df.iloc[0] = begin_value
-            index_ret_df = pd.DataFrame(index_ret_df).rename(columns={0:f'{index_id} funds'})
-            df_sum = index_ret_df.cumsum().join(index_price[[index_id]]).copy()#.plot()
-            df_sum = df_sum / df_sum.iloc[0]
-            df_sum[f'{index_id}_ratio'] = df_sum[f'{index_id} funds'] / df_sum[index_id]
-            df_sum = df_sum[[f'{index_id}_ratio']].rename(columns={f'{index_id}_ratio':index_id})
-            res_index.append(df_sum.fillna(method='ffill'))
-            
-        df_plot = pd.concat(res_index, sort=True,axis=1).fillna(method='ffill')
-        if 'mmf' in df_plot:
-            df_plot=df_plot.drop('mmf',axis=1)
-        
+                fund_ret_combine = pd.DataFrame(fund_nav_i.pct_change(1).mean(axis=1).dropna())
+                _index_id_res.append(fund_ret_combine)
+            fund_combine_rets = pd.concat(_index_id_res).rename(columns={0:'funds'})
+            index_ret = index_price[[index_id]].loc[rebalance_date[0]: rebalance_date[-1]].pct_change(1).dropna()
+            price_ratio_index = (fund_combine_rets.join(index_ret)+1).cumprod()
+            price_ratio_index = pd.DataFrame(price_ratio_index['funds'] / price_ratio_index[index_id]).rename(columns={0:index_id})
+            _res.append(price_ratio_index)
+        df_plot = pd.concat(_res, axis=1, sort=False)
         res = []
         for index_id in df_plot:
-            _index_stats = Calculator.get_stat_result_from_df(df=df_plot.reset_index(), date_column='index', value_column=index_id).__dict__
+            _index_stats = Calculator.get_stat_result_from_df(df=df_plot.reset_index(), date_column='datetime', value_column=index_id).__dict__
             _index_stats['index_id'] = index_id 
             res.append(_index_stats)
         
